@@ -41,37 +41,6 @@
 
 #include "compat.h"
 
-static void
-test_basename (CuTest *tc)
-{
-	struct {
-		const char *in;
-		const char *out;
-	} fixtures[] = {
-		{ "/this/is/a/path", "path" },
-		{ "/this/is/a/folder/", "folder" },
-		{ "folder/", "folder" },
-		{ "/", "" },
-		{ "this", "this" },
-#ifdef OS_WIN32
-		{ "\\this\\is\\a\\path", "path" },
-		{ "\\this\\is\\a\\folder\\", "folder" },
-		{ "folder\\", "folder" },
-		{ "\\", "" },
-#endif
-		{ NULL },
-	};
-
-	char *out;
-	int i;
-
-	for (i = 0; fixtures[i].in != NULL; i++) {
-		out = p11_basename (fixtures[i].in);
-		CuAssertStrEquals (tc, fixtures[i].out, out);
-		free (out);
-	}
-}
-
 static void
 test_strndup (CuTest *tc)
 {
@@ -94,7 +63,6 @@ main (void)
 	CuSuite* suite = CuSuiteNew ();
 	int ret;
 
-	SUITE_ADD_TEST (suite, test_basename);
 	SUITE_ADD_TEST (suite, test_strndup);
 
 	CuSuiteRun (suite);
