@@ -44,7 +44,7 @@
 #include "hash.h"
 #include "debug.h"
 #include "index.h"
-#include "library.h"
+#include "message.h"
 #include "oid.h"
 #include "pkcs11x.h"
 
@@ -552,7 +552,7 @@ test_build_distant_end_date (CuTest *cu)
 	};
 
 	CK_ATTRIBUTE expected[] = {
-		{ CKA_END_DATE, },
+		{ CKA_END_DATE, "20671229", 8 },
 		{ CKA_START_DATE, "20130327", 8 },
 		{ CKA_INVALID },
 	};
@@ -562,18 +562,6 @@ test_build_distant_end_date (CuTest *cu)
 
 	setup (cu);
 
-	/*
-	 * On a 32-bit system, the end date will be too big to compute with
-	 * libc. So it'll be empty, since this is an optional field.
-	 */
-	if (sizeof (time_t) <= 4) {
-		expected[0].pValue = "";
-		expected[0].ulValueLen = 0;
-	} else {
-		expected[0].pValue = "20671229";
-		expected[0].ulValueLen = 8;
-	}
-
 	attrs = NULL;
 	rv = p11_builder_build (test.builder, test.index, &attrs, p11_attrs_dup (input));
 	CuAssertIntEquals (cu, CKR_OK, rv);
@@ -1150,7 +1138,7 @@ test_changed_trusted_certificate (CuTest *cu)
 		{ CKA_CLASS, &trust_assertion, sizeof (trust_assertion) },
 		{ CKA_X_PURPOSE, (void *)P11_OID_SERVER_AUTH_STR, sizeof (P11_OID_SERVER_AUTH_STR) - 1 },
 		{ CKA_LABEL, "Custom Label", 12 },
-		{ CKA_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
+		{ CKA_X_CERTIFICATE_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
 		{ CKA_X_ASSERTION_TYPE, &anchored_certificate, sizeof (anchored_certificate) },
 		{ CKA_ID, "cacert3", 7 },
 		{ CKA_INVALID },
@@ -1160,7 +1148,7 @@ test_changed_trusted_certificate (CuTest *cu)
 		{ CKA_CLASS, &trust_assertion, sizeof (trust_assertion) },
 		{ CKA_X_PURPOSE, (void *)P11_OID_CLIENT_AUTH_STR, sizeof (P11_OID_CLIENT_AUTH_STR) - 1 },
 		{ CKA_LABEL, "Custom Label", 12 },
-		{ CKA_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
+		{ CKA_X_CERTIFICATE_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
 		{ CKA_X_ASSERTION_TYPE, &anchored_certificate, sizeof (anchored_certificate) },
 		{ CKA_ID, "cacert3", 7 },
 		{ CKA_INVALID },
@@ -1466,7 +1454,7 @@ test_changed_dup_certificates (CuTest *cu)
 	static CK_ATTRIBUTE anchor_assertion[] = {
 		{ CKA_CLASS, &trust_assertion, sizeof (trust_assertion) },
 		{ CKA_X_PURPOSE, (void *)P11_OID_SERVER_AUTH_STR, sizeof (P11_OID_SERVER_AUTH_STR) - 1 },
-		{ CKA_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
+		{ CKA_X_CERTIFICATE_VALUE, (void *)test_cacert3_ca_der, sizeof (test_cacert3_ca_der) },
 		{ CKA_X_ASSERTION_TYPE, &anchored_certificate, sizeof (anchored_certificate) },
 		{ CKA_ID, "cacert3", 7 },
 		{ CKA_INVALID },
@@ -1722,7 +1710,6 @@ main (void)
 	int ret;
 
 	putenv ("P11_KIT_STRICT=1");
-	p11_library_init ();
 	p11_debug_init ();
 	/* p11_message_quiet (); */
 
