@@ -41,8 +41,8 @@
 
 #include "attrs.h"
 #include "debug.h"
-#include "library.h"
 #include "index.h"
+#include "message.h"
 
 #include "test-data.h"
 
@@ -1036,7 +1036,6 @@ main (void)
 	int ret;
 
 	putenv ("P11_KIT_STRICT=1");
-	p11_library_init ();
 	p11_debug_init ();
 	p11_message_quiet ();
 
